#[repr(transparent)]pub struct Pintsecsel(pub u32);Expand description
Pin interrupt secure select register
Tuple Fields
0: u32Implementations
Sourceimpl Pintsecsel
impl Pintsecsel
Sourcepub const fn intpin(&self) -> u8
pub const fn intpin(&self) -> u8
Pin number select for pin interrupt secure or pattern match engine input. For PIO0_x: INTPIN = x. PIO0_0 to PIO0_31 correspond to numbers 0 to 31.
Sourcepub const fn set_intpin(&mut self, val: u8)
pub const fn set_intpin(&mut self, val: u8)
Pin number select for pin interrupt secure or pattern match engine input. For PIO0_x: INTPIN = x. PIO0_0 to PIO0_31 correspond to numbers 0 to 31.